@@ -6,6 +6,7 @@ use std::io;
 use std::iter::{repeat, FromIterator};
 use std::str::{self, FromStr};
 
+use itertools::Itertools;
 use stats::{merge_all, Commute, MinMax, OnlineStats, Unsorted};
 use threadpool::ThreadPool;
 
@@ -22,16 +23,16 @@ use self::FieldType::{TDate, TFloat, TInteger, TNull, TUnicode, TUnknown};
 static USAGE: &str = "
 Computes basic statistics on CSV data.
 
-Basic statistics includes mean, median, mode, standard deviation, variance, sum,
-max and min values. Note that some statistics are expensive to compute, so they
-must be enabled explicitly. By default, the following statistics are reported for
-*every* column in the CSV data: mean, max, min, standard deviation and variance.
-The default set of statistics corresponds to statistics that can be computed
-efficiently on a stream of data (i.e., constant memory).
+Basic statistics includes sum, min/max, min/max length, mean, stddev, variance,
+quartiles, median, mode, cardinality & nullcount. Note that some statistics are
+expensive to compute, so they must be enabled explicitly. By default, the following
+statistics are reported for *every* column in the CSV data: sum, min/max values,
+min/max length, mean, stddev & variance. The default set of statistics corresponds to
+statistics that can be computed efficiently on a stream of data (i.e., constant memory).
 
 The data type of each column is also inferred (Unknown, NULL, Integer, Unicode,
 Float and Date). The date formats recognized can be found at
-https://docs.rs/dateparser/0.1.5/dateparser/#accepted-date-formats.
+https://docs.rs/dateparser/0.1.6/dateparser/#accepted-date-formats.
 
 Computing statistics on a large file can be made much faster if you create
 an index for it first with 'qsv index'.
@@ -45,14 +46,15 @@ stats options:
                            This is provided here because piping 'qsv select'
                            into 'qsv stats' will disable the use of indexing.
     --everything           Show all statistics available.
-    --mode                 Show the mode.
+    --mode                 Show the mode/s. Multimodal-aware.
                            This requires storing all CSV data in memory.
     --cardinality          Show the cardinality.
                            This requires storing all CSV data in memory.
     --median               Show the median.
                            This requires storing all CSV data in memory.
     --nullcount            Show the number of NULLs.
-    --quartiles            Show the quartiles.
+    --quartiles            Show the quartiles, the IQR, the lower/upper fences
+                           and skew.
                            This requires storing all CSV data in memory.
     --nulls                Include NULLs in the population size for computing
                            mean and standard deviation.
@@ -250,9 +252,13 @@ impl Args {
             fields.push("median");
         }
         if self.flag_quartiles || all {
+            fields.push("lower_fence");
             fields.push("q1");
-            fields.push("q2");
+            fields.push("q2_median");
             fields.push("q3");
+            fields.push("iqr");
+            fields.push("upper_fence");
+            fields.push("skew");
         }
         if self.flag_mode || all {
             fields.push("mode");
@@ -292,7 +298,7 @@ struct Stats {
     sum: Option<TypedSum>,
     minmax: Option<TypedMinMax>,
     online: Option<OnlineStats>,
-    mode: Option<Unsorted<Vec<u8>>>,
+    modes: Option<Unsorted<Vec<u8>>>,
     median: Option<Unsorted<f64>>,
     nullcount: u64,
     quartiles: Option<Unsorted<f64>>,
@@ -301,7 +307,7 @@ struct Stats {
 
 impl Stats {
     fn new(which: WhichStats) -> Stats {
-        let (mut sum, mut minmax, mut online, mut mode, mut median, mut quartiles) =
+        let (mut sum, mut minmax, mut online, mut modes, mut median, mut quartiles) =
             (None, None, None, None, None, None);
         if which.sum {
             sum = Some(Default::default());
@@ -313,7 +319,7 @@ impl Stats {
             online = Some(Default::default());
         }
         if which.mode || which.cardinality {
-            mode = Some(Default::default());
+            modes = Some(Default::default());
         }
         if which.median {
             median = Some(Default::default());
@@ -326,7 +332,7 @@ impl Stats {
             sum,
             minmax,
             online,
-            mode,
+            modes,
             median,
             nullcount: 0,
             quartiles,
@@ -346,7 +352,7 @@ impl Stats {
         if let Some(v) = self.minmax.as_mut() {
             v.add(t, sample)
         };
-        if let Some(v) = self.mode.as_mut() {
+        if let Some(v) = self.modes.as_mut() {
             v.add(sample.to_vec())
         };
         if sample_type.is_null() {
@@ -456,15 +462,28 @@ impl Stats {
                     pieces.push(empty());
                     pieces.push(empty());
                     pieces.push(empty());
+                    pieces.push(empty());
+                    pieces.push(empty());
+                    pieces.push(empty());
+                    pieces.push(empty());
                 }
             }
             Some((q1, q2, q3)) => {
+                let iqr = q3 - q1;
+                pieces.push((q1 - (1.5 * iqr)).to_string());
                 pieces.push(q1.to_string());
                 pieces.push(q2.to_string());
                 pieces.push(q3.to_string());
+                pieces.push(iqr.to_string());
+                pieces.push((q3 + (1.5 * iqr)).to_string());
+                // calculate skewnewss using Pearson's median skewness
+                // https://en.wikipedia.org/wiki/Skewness#Pearson's_second_skewness_coefficient_(median_skewness)
+                let _mean = self.online.unwrap().mean();
+                let _stddev = self.online.unwrap().stddev();
+                pieces.push(((3.0 * (_mean - q2)) / _stddev).to_string());
             }
         }
-        match self.mode.as_mut() {
+        match self.modes.as_mut() {
             None => {
                 if self.which.mode {
                     pieces.push(empty());
@@ -475,9 +494,12 @@ impl Stats {
             }
             Some(ref mut v) => {
                 if self.which.mode {
-                    let lossy =
-                        |s: Vec<u8>| -> String { String::from_utf8_lossy(&*s).into_owned() };
-                    pieces.push(v.mode().map_or("N/A".to_owned(), lossy));
+                    pieces.push(
+                        v.modes()
+                            .iter()
+                            .map(|c| String::from_utf8_lossy(c))
+                            .join(","),
+                    );
                 }
                 if self.which.cardinality {
                     pieces.push(v.cardinality().to_string());
@@ -497,7 +519,7 @@ impl Commute for Stats {
         self.sum.merge(other.sum);
         self.minmax.merge(other.minmax);
         self.online.merge(other.online);
-        self.mode.merge(other.mode);
+        self.modes.merge(other.modes);
         self.median.merge(other.median);
         self.nullcount += other.nullcount;
         self.quartiles.merge(other.quartiles);
