@@ -1,15 +1,16 @@
 extern crate byteorder;
+extern crate chrono;
 extern crate crossbeam_channel as channel;
 extern crate csv;
 extern crate csv_index;
 extern crate currency;
-extern crate chrono;
 extern crate dateparser;
 extern crate docopt;
 extern crate filetime;
 extern crate hlua;
-#[macro_use]
 extern crate lazy_static;
+extern crate itertools;
+#[cfg(feature = "mimalloc")]
 extern crate mimalloc;
 extern crate num_cpus;
 extern crate rand;
@@ -19,6 +20,9 @@ extern crate serde;
 extern crate serde_json;
 extern crate tabwriter;
 extern crate threadpool;
+extern crate indicatif;
+extern crate num_format;
+extern crate natural;
 extern crate uuid;
 
 use std::borrow::ToOwned;
@@ -31,6 +35,7 @@ use serde::Deserialize;
 
 use docopt::Docopt;
 
+#[cfg(feature = "mimalloc")]
 #[global_allocator]
 static GLOBAL: mimalloc::MiMalloc = mimalloc::MiMalloc;
 
@@ -81,6 +86,7 @@ macro_rules! command_list {
     partition   Partition CSV data based on a column value
     pseudo      Pseudonymise the values of a column
     sample      Randomly sample CSV data
+    scramble    Randomly scramble a CSV
     rename      Rename the columns of CSV data efficiently
     replace     Replace patterns in CSV data
     reverse     Reverse rows of CSV data
@@ -113,7 +119,7 @@ Options:
     --list        List all commands available.
     -h, --help    Display this message
     <command> -h  Display the command help message
-    --version     Print version info and exit
+    --version     Print version info, mem allocator, num_cpus then exit
 
 Commands:",
     command_list!()
@@ -199,6 +205,7 @@ enum Command {
     Replace,
     Reverse,
     Sample,
+    Scramble,
     Search,
     SearchSet,
     Select,
@@ -252,6 +259,7 @@ impl Command {
             Command::Replace => cmd::replace::run(argv),
             Command::Reverse => cmd::reverse::run(argv),
             Command::Sample => cmd::sample::run(argv),
+            Command::Scramble => cmd::scramble::run(argv),
             Command::Search => cmd::search::run(argv),
             Command::SearchSet => cmd::searchset::run(argv),
             Command::Select => cmd::select::run(argv),
